@@ -16,17 +16,20 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core.client_options import ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.cloud.accessapproval_v1.services.access_approval import pagers
 from google.cloud.accessapproval_v1.types import accessapproval
@@ -43,7 +46,7 @@ class AccessApprovalAsyncClient:
 
     -  The API has a collection of
        [ApprovalRequest][google.cloud.accessapproval.v1.ApprovalRequest]
-       resources, named ``approvalRequests/{approval_request_id}``
+       resources, named ``approvalRequests/{approval_request}``
     -  The API has top-level settings per Project/Folder/Organization,
        named ``accessApprovalSettings``
 
@@ -51,10 +54,10 @@ class AccessApprovalAsyncClient:
     at the Project/Folder/Organization level in the
     accessApprovalSettings, when there is a pending ApprovalRequest for
     them to act on. The ApprovalRequests can also optionally be
-    published to a Cloud Pub/Sub topic owned by the customer (for Beta,
-    the Pub/Sub setup is managed manually).
+    published to a Pub/Sub topic owned by the customer (contact support
+    if you would like to enable Pub/Sub notifications).
 
-    ApprovalRequests can be approved or dismissed. Google personel can
+    ApprovalRequests can be approved or dismissed. Google personnel can
     only access the indicated resource or resources if the request is
     approved (subject to some exclusions:
     https://cloud.google.com/access-approval/docs/overview#exclusions).
@@ -80,6 +83,16 @@ class AccessApprovalAsyncClient:
     DEFAULT_ENDPOINT = AccessApprovalClient.DEFAULT_ENDPOINT
     DEFAULT_MTLS_ENDPOINT = AccessApprovalClient.DEFAULT_MTLS_ENDPOINT
 
+    access_approval_settings_path = staticmethod(
+        AccessApprovalClient.access_approval_settings_path
+    )
+    parse_access_approval_settings_path = staticmethod(
+        AccessApprovalClient.parse_access_approval_settings_path
+    )
+    approval_request_path = staticmethod(AccessApprovalClient.approval_request_path)
+    parse_approval_request_path = staticmethod(
+        AccessApprovalClient.parse_approval_request_path
+    )
     common_billing_account_path = staticmethod(
         AccessApprovalClient.common_billing_account_path
     )
@@ -138,6 +151,42 @@ class AccessApprovalAsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return AccessApprovalClient.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> AccessApprovalTransport:
         """Returns the transport used by the client instance.
@@ -212,13 +261,34 @@ class AccessApprovalAsyncClient:
         filtered by state (pending, active, dismissed). The
         order is reverse chronological.
 
+
+        .. code-block::
+
+            from google.cloud import accessapproval_v1
+
+            def sample_list_approval_requests():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.ListApprovalRequestsMessage(
+                )
+
+                # Make the request
+                page_result = client.list_approval_requests(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.accessapproval_v1.types.ListApprovalRequestsMessage, dict]):
                 The request object. Request to list approval requests.
             parent (:class:`str`):
                 The parent resource. This may be
-                "projects/{project_id}", "folders/{folder_id}", or
-                "organizations/{organization_id}".
+                "projects/{project}",
+                "folders/{folder}", or
+                "organizations/{organization}".
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -239,7 +309,7 @@ class AccessApprovalAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -302,12 +372,31 @@ class AccessApprovalAsyncClient:
         r"""Gets an approval request. Returns NOT_FOUND if the request does
         not exist.
 
+
+        .. code-block::
+
+            from google.cloud import accessapproval_v1
+
+            def sample_get_approval_request():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.GetApprovalRequestMessage(
+                )
+
+                # Make the request
+                response = client.get_approval_request(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.accessapproval_v1.types.GetApprovalRequestMessage, dict]):
                 The request object. Request to get an approval request.
             name (:class:`str`):
-                Name of the approval request to
-                retrieve.
+                The name of the approval request to retrieve. Format:
+                "{projects|folders|organizations}/{id}/approvalRequests/{approval_request}"
 
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -325,7 +414,7 @@ class AccessApprovalAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -384,6 +473,25 @@ class AccessApprovalAsyncClient:
         FAILED_PRECONDITION if the request exists but is not in a
         pending state.
 
+
+        .. code-block::
+
+            from google.cloud import accessapproval_v1
+
+            def sample_approve_approval_request():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.ApproveApprovalRequestMessage(
+                )
+
+                # Make the request
+                response = client.approve_approval_request(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.accessapproval_v1.types.ApproveApprovalRequestMessage, dict]):
                 The request object. Request to approve an
@@ -442,6 +550,25 @@ class AccessApprovalAsyncClient:
         Returns FAILED_PRECONDITION if the request exists but is not in
         a pending state.
 
+
+        .. code-block::
+
+            from google.cloud import accessapproval_v1
+
+            def sample_dismiss_approval_request():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.DismissApprovalRequestMessage(
+                )
+
+                # Make the request
+                response = client.dismiss_approval_request(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.accessapproval_v1.types.DismissApprovalRequestMessage, dict]):
                 The request object. Request to dismiss an approval
@@ -493,13 +620,33 @@ class AccessApprovalAsyncClient:
         r"""Gets the settings associated with a project, folder,
         or organization.
 
+
+        .. code-block::
+
+            from google.cloud import accessapproval_v1
+
+            def sample_get_access_approval_settings():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.GetAccessApprovalSettingsMessage(
+                )
+
+                # Make the request
+                response = client.get_access_approval_settings(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.accessapproval_v1.types.GetAccessApprovalSettingsMessage, dict]):
                 The request object. Request to get access approval
                 settings.
             name (:class:`str`):
-                Name of the AccessApprovalSettings to
-                retrieve.
+                The name of the AccessApprovalSettings to retrieve.
+                Format:
+                "{projects|folders|organizations}/{id}/accessApprovalSettings"
 
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -518,7 +665,7 @@ class AccessApprovalAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -577,6 +724,25 @@ class AccessApprovalAsyncClient:
         organization. Settings to update are determined by the value of
         field_mask.
 
+
+        .. code-block::
+
+            from google.cloud import accessapproval_v1
+
+            def sample_update_access_approval_settings():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.UpdateAccessApprovalSettingsMessage(
+                )
+
+                # Make the request
+                response = client.update_access_approval_settings(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.accessapproval_v1.types.UpdateAccessApprovalSettingsMessage, dict]):
                 The request object. Request to update access approval
@@ -616,7 +782,7 @@ class AccessApprovalAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([settings, update_mask])
         if request is not None and has_flattened_params:
@@ -674,6 +840,22 @@ class AccessApprovalAsyncClient:
         still be enabled at this level as the settings are
         inherited.
 
+
+        .. code-block::
+
+            from google.cloud import accessapproval_v1
+
+            def sample_delete_access_approval_settings():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.DeleteAccessApprovalSettingsMessage(
+                )
+
+                # Make the request
+                client.delete_access_approval_settings(request=request)
+
         Args:
             request (Union[google.cloud.accessapproval_v1.types.DeleteAccessApprovalSettingsMessage, dict]):
                 The request object. Request to delete access approval
@@ -692,7 +874,7 @@ class AccessApprovalAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
