@@ -14,23 +14,25 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
 from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
-OptionalRetry = Union[retries.Retry, object]
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
 
 from google.cloud.accessapproval_v1.services.access_approval import pagers
 from google.cloud.accessapproval_v1.types import accessapproval
@@ -80,7 +82,7 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
 
     -  The API has a collection of
        [ApprovalRequest][google.cloud.accessapproval.v1.ApprovalRequest]
-       resources, named ``approvalRequests/{approval_request_id}``
+       resources, named ``approvalRequests/{approval_request}``
     -  The API has top-level settings per Project/Folder/Organization,
        named ``accessApprovalSettings``
 
@@ -88,10 +90,10 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
     at the Project/Folder/Organization level in the
     accessApprovalSettings, when there is a pending ApprovalRequest for
     them to act on. The ApprovalRequests can also optionally be
-    published to a Cloud Pub/Sub topic owned by the customer (for Beta,
-    the Pub/Sub setup is managed manually).
+    published to a Pub/Sub topic owned by the customer (contact support
+    if you would like to enable Pub/Sub notifications).
 
-    ApprovalRequests can be approved or dismissed. Google personel can
+    ApprovalRequests can be approved or dismissed. Google personnel can
     only access the indicated resource or resources if the request is
     approved (subject to some exclusions:
     https://cloud.google.com/access-approval/docs/overview#exclusions).
@@ -194,6 +196,33 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         """
         return self._transport
 
+    @staticmethod
+    def access_approval_settings_path(project: str,) -> str:
+        """Returns a fully-qualified access_approval_settings string."""
+        return "projects/{project}/accessApprovalSettings".format(project=project,)
+
+    @staticmethod
+    def parse_access_approval_settings_path(path: str) -> Dict[str, str]:
+        """Parses a access_approval_settings path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)/accessApprovalSettings$", path)
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def approval_request_path(project: str, approval_request: str,) -> str:
+        """Returns a fully-qualified approval_request string."""
+        return "projects/{project}/approvalRequests/{approval_request}".format(
+            project=project, approval_request=approval_request,
+        )
+
+    @staticmethod
+    def parse_approval_request_path(path: str) -> Dict[str, str]:
+        """Parses a approval_request path into its component segments."""
+        m = re.match(
+            r"^projects/(?P<project>.+?)/approvalRequests/(?P<approval_request>.+?)$",
+            path,
+        )
+        return m.groupdict() if m else {}
+
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
         """Returns a fully-qualified billing_account string."""
@@ -253,6 +282,73 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -303,50 +399,22 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, AccessApprovalTransport):
             # transport is a AccessApprovalTransport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -358,6 +426,15 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -384,13 +461,35 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         filtered by state (pending, active, dismissed). The
         order is reverse chronological.
 
+
+
+        .. code-block::
+
+            from google.cloud import accessapproval_v1
+
+            def sample_list_approval_requests():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.ListApprovalRequestsMessage(
+                )
+
+                # Make the request
+                page_result = client.list_approval_requests(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
             request (Union[google.cloud.accessapproval_v1.types.ListApprovalRequestsMessage, dict]):
                 The request object. Request to list approval requests.
             parent (str):
                 The parent resource. This may be
-                "projects/{project_id}", "folders/{folder_id}", or
-                "organizations/{organization_id}".
+                "projects/{project}",
+                "folders/{folder}", or
+                "organizations/{organization}".
 
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -411,7 +510,7 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -465,12 +564,32 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         r"""Gets an approval request. Returns NOT_FOUND if the request does
         not exist.
 
+
+
+        .. code-block::
+
+            from google.cloud import accessapproval_v1
+
+            def sample_get_approval_request():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.GetApprovalRequestMessage(
+                )
+
+                # Make the request
+                response = client.get_approval_request(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.accessapproval_v1.types.GetApprovalRequestMessage, dict]):
                 The request object. Request to get an approval request.
             name (str):
-                Name of the approval request to
-                retrieve.
+                The name of the approval request to retrieve. Format:
+                "{projects|folders|organizations}/{id}/approvalRequests/{approval_request}"
 
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -488,7 +607,7 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -538,6 +657,26 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         FAILED_PRECONDITION if the request exists but is not in a
         pending state.
 
+
+
+        .. code-block::
+
+            from google.cloud import accessapproval_v1
+
+            def sample_approve_approval_request():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.ApproveApprovalRequestMessage(
+                )
+
+                # Make the request
+                response = client.approve_approval_request(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.accessapproval_v1.types.ApproveApprovalRequestMessage, dict]):
                 The request object. Request to approve an
@@ -597,6 +736,26 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         Returns FAILED_PRECONDITION if the request exists but is not in
         a pending state.
 
+
+
+        .. code-block::
+
+            from google.cloud import accessapproval_v1
+
+            def sample_dismiss_approval_request():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.DismissApprovalRequestMessage(
+                )
+
+                # Make the request
+                response = client.dismiss_approval_request(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.accessapproval_v1.types.DismissApprovalRequestMessage, dict]):
                 The request object. Request to dismiss an approval
@@ -649,13 +808,34 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         r"""Gets the settings associated with a project, folder,
         or organization.
 
+
+
+        .. code-block::
+
+            from google.cloud import accessapproval_v1
+
+            def sample_get_access_approval_settings():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.GetAccessApprovalSettingsMessage(
+                )
+
+                # Make the request
+                response = client.get_access_approval_settings(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.accessapproval_v1.types.GetAccessApprovalSettingsMessage, dict]):
                 The request object. Request to get access approval
                 settings.
             name (str):
-                Name of the AccessApprovalSettings to
-                retrieve.
+                The name of the AccessApprovalSettings to retrieve.
+                Format:
+                "{projects|folders|organizations}/{id}/accessApprovalSettings"
 
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
@@ -674,7 +854,7 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -726,6 +906,26 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         organization. Settings to update are determined by the value of
         field_mask.
 
+
+
+        .. code-block::
+
+            from google.cloud import accessapproval_v1
+
+            def sample_update_access_approval_settings():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.UpdateAccessApprovalSettingsMessage(
+                )
+
+                # Make the request
+                response = client.update_access_approval_settings(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
             request (Union[google.cloud.accessapproval_v1.types.UpdateAccessApprovalSettingsMessage, dict]):
                 The request object. Request to update access approval
@@ -765,7 +965,7 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([settings, update_mask])
         if request is not None and has_flattened_params:
@@ -825,6 +1025,23 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
         still be enabled at this level as the settings are
         inherited.
 
+
+
+        .. code-block::
+
+            from google.cloud import accessapproval_v1
+
+            def sample_delete_access_approval_settings():
+                # Create a client
+                client = accessapproval_v1.AccessApprovalClient()
+
+                # Initialize request argument(s)
+                request = accessapproval_v1.DeleteAccessApprovalSettingsMessage(
+                )
+
+                # Make the request
+                client.delete_access_approval_settings(request=request)
+
         Args:
             request (Union[google.cloud.accessapproval_v1.types.DeleteAccessApprovalSettingsMessage, dict]):
                 The request object. Request to delete access approval
@@ -843,7 +1060,7 @@ class AccessApprovalClient(metaclass=AccessApprovalClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
